# Skripti modailtu ChatGPT avulla, piirsi kuvaajan kohtisuoraan skets tasoa vasten, mikä aiheutti kaikenlaista ongelmaa.
# Samalla skaalasin unitsit milleihin, ja muutin Z akselit negatiivisiksi kun tuntuu olevan kurvit ylösalasi
# T 19.10.2024. 
import adsk.core, adsk.fusion, traceback

def run(context):
    ui = None
    try:
        title = 'Ath4 Curves Import'
        app = adsk.core.Application.get()
        ui = app.userInterface
        design = app.activeProduct
        if not design:
            ui.messageBox('No active Fusion design', title)
            return
        
        # Get the current selection or use the root component as a fallback
        current_selection = ui.activeSelections
        if current_selection.count > 0:
            # If there is a selected component, use it
            selected_component = current_selection.item(0).entity
            if not isinstance(selected_component, adsk.fusion.Component):
                ui.messageBox('Please select a valid component.', title)
                return
        else:
            # If no component is selected, fall back to the root component
            selected_component = design.rootComponent

        dlg = ui.createFileDialog()
        dlg.title = 'Open Ath4 Coordinate File'
        dlg.filter = 'Comma Separated Values (*.csv);;All Files (*.*)'
        if dlg.showOpen() != adsk.core.DialogResults.DialogOK:
            return

        filename = dlg.filename
        f = open(filename, 'r')
        points = adsk.core.ObjectCollection.create()        
        points_array = []
        line = f.readline()
        while line:                    
            if line[0] == '#':
                line = f.readline()
                continue
            if line in ['\n', '\r\n']:
                # Only store the points collection if it's not empty
                if len(points) > 0:
                    points_array.append(points)
                    points = adsk.core.ObjectCollection.create()
            else:
                pntStrArr = line.split(';')
                if len(pntStrArr) >= 3:
                    # Convert from cm to mm by multiplying by 0.1 and flip Z-axis
                    x = float(pntStrArr[0]) * 0.1
                    z = float(pntStrArr[2]) * 0.1 * -1  # Multiply Z by -1 to flip
                    
                    # Here, convert the 3D point into a 2D point for the XZ sketch
                    points.add(adsk.core.Point3D.create(x, z, 0))  # Sketch expects 2D points
                    
            line = f.readline()
        f.close()

        # Add any remaining points to the array if not added yet
        if len(points) > 0:
            points_array.append(points)

        # Iterate over points arrays and create sketches in the selected component
        for pa in points_array:
            if len(pa) > 0:  # Only create sketch if there are points
                sketch = selected_component.sketches.add(selected_component.xZConstructionPlane)  # Use XZ plane of selected component
                sketch.sketchCurves.sketchFittedSplines.add(pa)

    except:
        if ui:
            ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
